<?php

namespace Drupal\bazaarvoice_productfeed\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Class AttributesAddForm.
 *
 * @package Drupal\bazaarvoice_productfeed\Form
 */
class AttributesDeleteForm extends ConfirmFormBase {

  /**
   * The ID of the item to delete.
   *
   * @var string
   */
  protected $attribute;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'bazaarvoice_productfeed_attributes_delete_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return t('Do you want to delete attribute @id?', ['@id' => $this->attribute['attribute']]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('bazaarvoice_productfeed.attributes');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return t('You will not be able to restore @label if you confirm the deletion!', ['@label' => $this->attribute['label']]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return t('Confirm');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelText() {
    return t('Cancel');
  }

  /**
   * {@inheritdoc}
   *
   * @param int $bv_attribute
   *   (optional) The ID of the item to be deleted.
   */
  public function buildForm(array $form, FormStateInterface $form_state, $bv_attribute = NULL) {
    $this->attribute = $bv_attribute;
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $bv_attribute = $this->attribute['attribute'];

    // Delete attribute.
    bazaarvoice_productfeed_delete_attributes(array($bv_attribute));

    // Let user know attribute was successfully deleted.
    drupal_set_message(t('Attribute "@attribute" has been deleted.', array('@attribute' => $this->attribute['label'])), 'status', TRUE);

    // Redirect to the attributes admin page.
    $response = new RedirectResponse('/admin/config/services/bazaarvoice/productfeed/attributes');
    $response->send();
  }

}
