<?php

namespace Drupal\bazaarvoice_reviews\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityInterface;
use Drupal\node\NodeInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * View Reviews Controller.
 */
class BazaarvoiceReviewsViewReviewsController extends ControllerBase {

  /**
   * The _title_callback for the page that renders a single node in preview.
   *
   * @param \Drupal\Core\Entity\EntityInterface $node_preview
   *   The current node.
   *
   * @return string
   *   The page title.
   */
  public function title(NodeInterface $node) {
    return $this->entityManager->getTranslationFromContext($node)->label();
  }

  /**
   * {@inheritdoc}
   */
  public function view(NodeInterface $node, Request $request) {
    $build = [];

    module_load_include('module', 'bazaarvoice_products');
    module_load_include('inc', 'bazaarvoice_reviews', 'includes/reviews');

    // Attempt to get product info.
    $entity = $node;
    $type = $entity->getEntityType()->getProvider();
    $bundle = $entity->bundle();

    if ($product_info = bazaarvoice_products_get_product_info($type, $entity)) {
      $review_link = '';
      // User have access to provide reviews?
      if (\Drupal::currentUser()->hasPermission('submit bazaarvoice reviews')) {
        $review_link = bazaarvoice_reviews_product_write_a_review_link($product_info['type'], $product_info['eid']);
      }

      // Attempt to retrieve arrays for this product/locale.
      if ($reviews = bazaarvoice_reviews_get_reviews($product_info['product_id'])) {
        $build = array(
          '#theme' => 'bazaarvoice_reviews_reviews',
          '#reviews' => array(),
          '#product_info' => $product_info,
          '#review_link' => $review_link,
          '#pager' => array(
            '#theme' => 'pager',
            '#quantity' => count($reviews),
          ),
        );
        // Get how many reviews to display per page.
        $per_page = \Drupal::config('bazaarvoice_reviews.settings')
          ->get('reviews_per_page');
        // Initialize a pages.
        $current_page = pager_default_initialize(count($reviews), $per_page);
        // Split the current reviews into chunks.
        $chunks = array_chunk($reviews, $per_page, TRUE);
        foreach ($chunks[$current_page] as $review) {
          $build['#reviews'][] = array(
            '#theme' => 'bazaarvoice_reviews_review',
            '#review' => $review,
          );
        }

      }
      // No reviews, display a message.
      else {
        $build = array(
          '#type' => 'markup',
          '#markup' => t('There are no reviews. @review_link', array(
            '@review_link' => $review_link->toString(),
          )),
        );
      }
    }

    return $build;
  }

}
