<?php

namespace Drupal\bazaarvoice_reviews\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Utility\Html;

/**
 * Class BazaarvoiceReviewsAddReviewForm.
 *
 * @package Drupal\bazaarvoice_reviews\Form
 */
class BazaarvoiceReviewsAddReviewForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'bazaarvoice_reviews_add_review_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, array $product_info = NULL) {

    $values = $form_state->getValues();
    $form['#product_info'] = $product_info;
    // Get previously submitted values.
    $previous_values = isset($values) ? $values : array();
    // Get the Bazaarvoice form fields.
    if ($fields = bazaarvoice_reviews_get_conversations_drupal_fields($product_info['product_id'])) {
      // Set default values.
      bazaarvoice_reviews_set_conversations_field_values($fields, $previous_values);
      // Add the fields to the forms.
      $form += $fields;
    }

    // Add device fingerprinting.
    // See: https://developer.bazaarvoice.com/apis/conversations/tutorials/device_fingerprinting
    $form['fp'] = array(
      '#type' => 'hidden',
      '#attributes' => array(
        'id' => 'fp',
        'value' => '',
      ),
      '#attached' => [
        'library' => [
          'bazaarvoice_reviews/bv_reviews_snare',
        ],
      ],
    );

    $form['actions'] = array('#type' => 'actions');
    // Submit button.
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
      '#weight' => 1000,
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // Get product info.
    $product_info = $form['#product_info'];
    // Get submitted values.
    $values = $form_state->getValues();

    // Validate the conversation fields. Any errors?
    if ($errors = bazaarvoice_reviews_conversations_field_errors($product_info['product_id'], $values)) {
      // Loop through all of the errors.
      foreach ($errors as $field_id => $field_errors) {
        // For each error on a field.
        foreach ($field_errors as $error) {
          // Print a form error.
          $form_state->setErrorByName($field_id, Html::escape($error));
        }
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Get product info.
    $product_info = $form['#product_info'];
    $values = $form_state->getValues();

    // Attempt to submit review.
    if ($submit = bazaarvoice_reviews_submit_conversation_review($product_info['product_id'], $values)) {
      // Any errors?
      if (isset($submit['errors'])) {
        // Print errors.
        foreach ($submit['errors'] as $error) {
          drupal_set_message(Html::escape($error), 'error');
        }
      }
      else {
        $message = t('Your review has been submitted.');
        if (isset($submit['success'])) {
          $message = $submit['success'];
        }
        drupal_set_message(Html::escape($message));
        // Redirect to product page?
        drupal_goto($product_info['type'] . '/' . $product_info['eid']);
      }
    }
    // Not able to submit, return generic error.
    else {
      drupal_set_message(t('There was an error submitting your review'), 'error');
    }
  }

}
