<?php

namespace Drupal\bazaarvoice_ui\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Link;

/**
 * Class BazaarvoiceUiAdminSettingsForm.
 *
 * @package Drupal\bazaarvoice_ui\Form
 */
class BazaarvoiceUiAdminSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'bazaarvoice_ui_admin_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['bazaarvoice_ui.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('bazaarvoice_ui.settings');

    $form['account'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Account Settings'),
      '#description' => $this->t('Bazaarvoice account settings'),
      '#collapsible' => TRUE,
    ];

    $form['account']['mode'] = [
      '#type' => 'select',
      '#title' => $this->t('Account Mode'),
      '#description' => $this->t('Mode to use for connecting to Bazaarvoice. Use staging for pre-production development and testing.'),
      '#options' => [
        'stg' => $this->t('Staging'),
        'prod' => $this->t('Production'),
      ],
      '#default_value' => $config->get('mode'),
    ];

    $form['account']['client_code'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client code'),
      '#required' => TRUE,
      '#description' => $this->t('The client code for the Bazaarvoice account.'),
      '#default_value' => $config->get('client_code'),
    ];

    $form['api'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Conversations API Settings'),
      '#description' => $this->t('Settings for connecting to the Bazaarvoice Conversations API.'),
      '#collapsible' => TRUE,
    ];

    $form['api']['passKey'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pass Key'),
      '#required' => TRUE,
      '#description' => $this->t('API key is required to authenticate API user and check permission to access particular client data.  If you do not have an API key you can get one @url', [
        '@url' => Link::fromTextAndUrl(t('here'), Url::fromUri('https://developer.bazaarvoice.com/apps/register'))
          ->toString(),
      ]),
      '#size' => 40,
      '#maxlength' => 255,
      '#default_value' => $config->get('passKey'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    foreach ($values as $key => $value) {
      $this->configFactory()->getEditable('bazaarvoice_ui.settings')
        ->set($key, $value)
        ->save();
    }

    parent::submitForm($form, $form_state);
  }

}
